@@ -9,10 +9,7 @@ from . import state
 from .utils import disabled_imports, init_base_event, load_config
 from .version import VERSION
 
-functions = {
-    name: func
-    for (name, func) in inspect.getmembers(functions_module, inspect.isfunction)
-}
+functions = {name: func for (name, func) in inspect.getmembers(functions_module, inspect.isfunction)}
 events = {
     name: event
     for (name, event) in inspect.getmembers(events_module, inspect.isclass)
@@ -29,7 +26,8 @@ def run(source, filename="<string>", config=None, plugins=[]):
         with disabled_imports():
             code = compile(source, filename, "exec")
             exec(
-                code, {**context, **functions, **events},
+                code,
+                {**context, **functions, **events},
             )
     except BaseException:
         stack_frames = len(traceback.extract_tb(sys.exc_info()[2])) - 1
