@@ -8,21 +8,11 @@ pytestmark = pytest.mark.slow
 
 
 def test_user_agent():
-    assert (
-        run(
-            f"assert http.get('http://httpbin.org/user-agent').json() == {{'user-agent': 'bitccl/{VERSION}'}}"
-        )
-        is None
-    )
+    assert run(f"assert http.get('http://httpbin.org/user-agent').json() == {{'user-agent': 'bitccl/{VERSION}'}}") is None
 
 
 def test_http2_enabled():
-    assert (
-        run(
-            "assert http.get('https://nghttp2.org/httpbin/status/200').http_version == 'HTTP/2'"
-        )
-        is None
-    )
+    assert run("assert http.get('https://nghttp2.org/httpbin/status/200').http_version == 'HTTP/2'") is None
 
 
 def test_status_codes():
